Learn R Programming

rattle (version 5.6.2)

find_fewest_levels: Identify the categoric columns with the fewest values.

Description

Return the name of the categoric columns with the fewest values.

Usage

find_fewest_levels(df)

Arguments

df

A data frame.

Details

A function to identify the categorical column with the fewest unique values This is used by Rattle V6 to identify potential target variables.