whichNumerics: Returns a list of the names of the numeric variables in a...

View source: R/data.R

whichNumericsR Documentation

Returns a list of the names of the numeric variables in a data frame.

Description

A rattle support function.

Usage

whichNumerics(data)

Arguments

data

a data frame.

Author(s)

Graham.Williams@togaware.com

References

Package home page: https://togaware.com/projects/rattle/


rattle documentation built on Feb. 9, 2026, 1:07 a.m.