Generate a matrix of centers from a hierarchical cluster.
centers.hclust(x, object, nclust=10, use.median=FALSE)
The data used to build the cluster.
A hclust object.
Number of clusters.
Use meadion instead of mean.
Daniele Medri and Graham.Williams@togaware.com
For the specified number of clusters, cut the hierarchical cluster appropriately to that number of clusters, and return the mean (or median) of each resulting cluster.
Package home page: https://rattle.togaware.com