powered by
Return the name of the categoric columns with the fewest values.
find_fewest_levels(df)
A data frame.
A function to identify the categorical column with the fewest unique values This is used by Rattle V6 to identify potential target variables.